@@ -2,7 +2,7 @@ from eda_report.cli import process_cli_args
 from eda_report.document import ReportDocument
 from eda_report.gui import EDAGUI
 
-__version__ = "1.4.0"
+__version__ = "1.6.1"
 
 
 def get_word_report(
@@ -13,14 +13,14 @@ def get_word_report(
     output_filename="eda-report.docx",
     target_variable=None
 ):
-    """Analyses the input data, and generates a report in *.docx* format.
+    """Analyses input data, and generates a report in *Word* (*.docx*) format.
 
     This is simply a wrapper around the
     :class:`~eda_report.document.ReportDocument` object, and the arguments
     supplied are passed to it.
 
     :param data: The data to analyse.
-    :type data: an array-like or sequence.
+    :type data: array-like, sequence, iterable.
     :param title: The top level heading for the generated report, defaults to
         'Exploratory Data Analysis Report'.
     :type title: str, optional
@@ -28,12 +28,12 @@ def get_word_report(
         to 'orangered'. See the *matplotlib* `list of named colors`_ for all
         available options.
     :type graph_color: str, optional
-    :param output_filename: The name and path to use in saving the generated
-        report file, defaults to 'eda-report.docx' in the current directory.
+    :param output_filename: The name and path for the generated report file,
+        defaults to 'eda-report.docx'.
     :type output_filename: str, optional
-    :param target_variable: The target variable (dependent feature), used to
-        color-code plotted values. An *integer value* is treated as a *column
-        index*, whereas a *string* is treated as a *column label*.
+    :param target_variable: The dependent feature. Used to color-code plotted
+        values. An *integer value* is treated as a *column index*, whereas a
+        *string* is treated as a *column label*.
     :type target_variable: int, str, optional
 
     .. _`list of named colors`:
@@ -49,8 +49,8 @@ def get_word_report(
     )
 
 
-def run_from_cli():
-    """Creates an exploratory data analysis report in *.docx* format using input
+def run_from_cli():  # pragma: no cover
+    """Creates an exploratory data analysis report in *Word* format using input
     from the command line interface.
 
     This is the function executed when the package is run as a script (using
@@ -73,7 +73,7 @@ def run_from_cli():
     )
 
 
-def run_in_gui():
+def run_in_gui():  # pragma: no cover
     """Starts the *graphical user interface* to the application.
 
     This provides the entry point for the ``eda_report`` console script
