@@ -33,9 +33,9 @@ class MultiVariable:
             defaults to 'orangered'. See the *matplotlib* `list of named
             colors`_ for all available options.
         :type graph_color: str, optional
-        :param target_variable: The target variable (dependent feature). An
-            *integer value* is treated as a *column index*, whereas a *string*
-            is treated as a *column label*.
+        :param target_variable: The dependent feature. Used to color-code
+            plotted values. An *integer value* is treated as a *column index*,
+            whereas a *string* is treated as a *column label*.
         :type target_variable: int, str, optional
 
         .. _`list of named colors`:
@@ -47,17 +47,18 @@ class MultiVariable:
         self.TARGET_VARIABLE = validate_target_variable(
             data=self.data, target_variable=target_variable
         )
+        self._COLOR_CODED_GRAPHS = set()
         #: A ``DataFrame`` with all the *numeric columns/features* present.
         self.numeric_cols = self._select_cols("number")
         #: A ``DataFrame`` with all the *categorical columns/features*
-        #: present. Please note that **boolean features** are also
-        #: **considered categorical** in this context.
+        #: present. Please note that **boolean** and **datetime** features are
+        #: also **considered categorical** in this context.
         self.categorical_cols = self._select_cols("object", "bool")
         #: A ``DataFrame`` of Pearson correlation coefficients for the
         #: *numeric columns/features*.
         self.correlation_df = self._get_correlation()
         #: Get brief descriptions of the nature of correlation between
-        #: numerical feature pairs.
+        #: numerical features.
         self.corr_type = {}
         self.bivariate_scatterplots = {}
         self._get_bivariate_analysis()
@@ -95,7 +96,7 @@ Categorical features: {', '.join(categorical_cols)}
 {self._corr_description if hasattr(self, '_corr_description') else 'N/A'}
 """
 
-    def show_correlation_heatmap(self):
+    def show_correlation_heatmap(self):  # pragma: no cover
         """Display a heatmap of Pearson correlation coefficients for all
         *numeric columns/features* present.
         """
@@ -105,7 +106,7 @@ Categorical features: {', '.join(categorical_cols)}
         else:
             logging.info("Not enough numeric variables to compare.")
 
-    def show_joint_scatterplot(self):
+    def show_joint_scatterplot(self):  # pragma: no cover
         """Display a joint scatter-plot of all the *numeric columns/features*
         present.
         """
@@ -131,7 +132,7 @@ Categorical features: {', '.join(categorical_cols)}
         """Get a DataFrame of the correlation coefficients for numeric
         columns.
         """
-        return None if self.numeric_cols is None else self.data.corr()
+        return None if self.numeric_cols is None else self.numeric_cols.corr()
 
     def _get_bivariate_analysis(self):
         """Compare numeric variable pairs."""
@@ -142,7 +143,9 @@ Categorical features: {', '.join(categorical_cols)}
             self._corr_description = "\n".join(
                 [
                     f"{var_pair[0]} & {var_pair[1]} --> {corr_description}"
-                    for var_pair, corr_description in self.corr_type.items()
+                    for var_pair, corr_description in sorted(
+                        self.corr_type.items()
+                    )
                 ]
             )
         else:
@@ -151,59 +154,40 @@ Categorical features: {', '.join(categorical_cols)}
                 "Not enough numeric variables to compare."
             )
 
-    def _create_palette(self, n_colors=10):
-        """Get a color palette based on the set graph color."""
-        return sns.light_palette(self.graph_color, n_colors=n_colors + 1,)[
-            1:  # Discard the first, which is too light
-        ]
-
     def _plot_joint_scatterplot(self):
         """Create a joint scatter-plot of all numeric columns."""
-        if self.TARGET_VARIABLE is not None:
-            target_data = self.data[self.TARGET_VARIABLE]
-
-            if target_data.nunique() > 10:
-                # Too many levels in target variable would clutter the graph
-                logging.warning(
-                    f"Target variable '{target_data.name}' not used to group "
-                    "values in joint scatterplot. It has too many levels "
-                    f"({target_data.nunique()}), and would clutter the graph."
-                )
-                # Treat target variable as if None
-                plot_params = {"data": self.numeric_cols}
-                subplot_params = {"color": self.graph_color}
-
-            elif target_data.nunique() in range(1, 11):
-                # Color-code plotted values by target variable
-                if self.TARGET_VARIABLE in self.numeric_cols:
-                    numeric_cols_with_target = self.numeric_cols
-                else:  # Combine the numeric data and target data
-                    numeric_cols_with_target = self.numeric_cols.merge(
-                        target_data,
-                        left_index=True,
-                        right_index=True,
-                    )
-                plot_params = {
-                    "data": numeric_cols_with_target,
-                    "hue": self.TARGET_VARIABLE,
-                    "palette": self._create_palette(
-                        n_colors=self.data[self.TARGET_VARIABLE].nunique()
-                    ),
-                }
-                subplot_params = {}
-
-        else:  # When self.TARGET_VARIABLE is None
+        if (
+            self.TARGET_VARIABLE is None
+            or self.data[self.TARGET_VARIABLE].nunique() > 10
+        ):
             plot_params = {"data": self.numeric_cols}
             subplot_params = {"color": self.graph_color}
 
+        else:  # Color-code plotted values by target variable
+            if self.TARGET_VARIABLE in self.numeric_cols:
+                numeric_cols_with_target = self.numeric_cols
+            else:  # Join the numeric data and target-variable data by index
+                numeric_cols_with_target = self.numeric_cols.merge(
+                    self.data[self.TARGET_VARIABLE],
+                    left_index=True,
+                    right_index=True,
+                )
+            plot_params = {
+                "data": numeric_cols_with_target,
+                "hue": self.TARGET_VARIABLE,
+                "palette": f"dark:{self.graph_color}_r",
+            }
+            subplot_params = {}
+            self._COLOR_CODED_GRAPHS.add("joint-scatterplot")
+
         fig = sns.PairGrid(**plot_params)
         fig.map_upper(  # Plot scatterplots in upper half
             sns.scatterplot, **subplot_params
         )
-        fig.map_lower(  # Plot scatterplots in upper half
+        fig.map_lower(  # Plot kdeplots in lower half
             sns.kdeplot, **subplot_params
         )
-        fig.map_diag(  # Plot scatterplots in diagonal
+        fig.map_diag(  # Plot histograms in diagonal
             sns.histplot, kde=True, **subplot_params
         )
         fig.add_legend(bbox_to_anchor=(1.05, 1.05))
@@ -220,7 +204,7 @@ Categorical features: {', '.join(categorical_cols)}
             yticklabels=True,
             mask=np.triu(self.correlation_df),
             ax=ax,
-            cmap=self._create_palette(n_colors=self.correlation_df.shape[1]),
+            cmap=sns.light_palette(self.graph_color, as_cmap=True),
         )
         ax.tick_params(rotation=45)
         fig.suptitle("Correlation in Numeric Columns", size=15)
@@ -296,7 +280,7 @@ Categorical features: {', '.join(categorical_cols)}
         sns.ecdfplot(
             data=self.data.loc[:, [var1, var2]],
             ax=ax2,
-            palette=self._create_palette(n_colors=2),
+            palette=f"dark:{self.graph_color}_r",
         )
         ax1.set_title(f"Scatter-plot - {var1} vs {var2}".title(), size=9)
         ax2.set_title("Empirical Cummulative Distribution Functions", size=9)
