@@ -1,7 +1,11 @@
 from textwrap import shorten
 
 import seaborn as sns
-from pandas.api.types import is_bool_dtype, is_numeric_dtype
+from pandas.api.types import (
+    is_bool_dtype,
+    is_datetime64_any_dtype,
+    is_numeric_dtype,
+)
 from PIL import Image
 from scipy.stats import probplot
 
@@ -20,13 +24,13 @@ class Variable:
         """Initialise an instance of :class:`Variable`.
 
         :param data: The data to process.
-        :type data: :class:`pandas.Series`.
+        :type data: array-like, sequence, iterable.
         :param graph_color: The color to apply to the graphs created,
             defaults to 'orangered'.
         :type graph_color: str, optional
         :param name: The feature's name.
         :type name: str, optional
-        :param target_data: The data for the target variable (dependent
+        :param target_data: Data for the target variable (dependent
             feature). Currently used to group and color-code values in graphs.
         :type target_data: array-like, optional
         """
@@ -35,7 +39,8 @@ class Variable:
         #: argument during instantiation, this will be taken as the value of
         #: the ``name`` attribute of the input data.
         self.name = self._get_name(name)
-        #: The *type* of feature; either *categorical* or *numeric*.
+        #: The *type* of feature; either *boolean*, *categorical*, *datetime*
+        #:  or *numeric*.
         self.var_type = self._get_variable_type()
         #: *Summary statistics* for the *column/feature*, as a
         #: :class:`pandas.DataFrame`.
@@ -44,11 +49,12 @@ class Variable:
         self.num_unique = self.data.nunique()
         #: The set of *unique values* present in the *column/feature*.
         self.unique = set(self.data.unique())
-        #: The number of *missing values* (``NaN``, ``None``, ``NA``, ...).
+        #: The number of *missing values*.
         self.missing = self._get_missing_values()
         #: The *color* applied to the created graphs.
         self.graph_color = graph_color
         self.TARGET_DATA = validate_univariate_input(target_data)
+        self._COLOR_CODED_GRAPHS = set()
         # Get graphs for the column/feature as a dict of file-like objects.
         self._graphs = self._plot_graphs()
 
@@ -67,7 +73,7 @@ Missing Values: {self.missing}
 {self.statistics}
 """
 
-    def show_graphs(self):
+    def show_graphs(self):  # pragma: no cover
         """Display the plotted graphs for the *column/feature*."""
         for graph in self._graphs.values():
             image = Image.open(graph)
@@ -86,19 +92,25 @@ Missing Values: {self.missing}
 
     def _get_variable_type(self):
         """Get the variable type: 'categorical' or 'numeric'."""
-        if is_numeric_dtype(self.data) and not is_bool_dtype(self.data):
-            # Only int and float types
-            return "numeric"
+        if is_numeric_dtype(self.data):
+            if is_bool_dtype(self.data) or set(self.data.dropna()) == {0, 1}:
+                return "boolean"
+            else:
+                # Only int and float types
+                return "numeric"
+        elif is_datetime64_any_dtype(self.data):
+            self.data = self.data.dt.strftime("%c")
+            return "datetime"
         else:
-            # Handle bool, string, datetime, etc as categorical
-            self.data = self.data.astype("category")
+            # Handle str, etc as categorical
             return "categorical"
 
     def _get_summary_statistics(self):
         """Get summary statistics for the column/feature."""
         if self.var_type == "numeric":
             return self._numeric_summary_statictics()
-        elif self.var_type == "categorical":
+        elif self.var_type in {"boolean", "categorical", "datetime"}:
+            self.data = self.data.astype("category")
             return self._categorical_summary_statistics()
 
     def _numeric_summary_statictics(self):
@@ -145,12 +157,6 @@ Missing Values: {self.missing}
         else:
             return f"{missing_values} ({missing_values / len(self.data):.2%})"
 
-    def _color_palette(self, n_colors):
-        """Get a color palette based on the set graph color."""
-        return sns.light_palette(self.graph_color, n_colors=n_colors + 1,)[
-            1:  # Discard the first, which is too light
-        ]
-
     def _plot_graphs(self):
         """Plot graphs for the column/feature, based on variable type."""
         if self.var_type == "numeric":
@@ -159,7 +165,7 @@ Missing Values: {self.missing}
                 "prob_plot": self._plot_prob_plot(),
                 "run_plot": self._plot_run_plot(),
             }
-        elif self.var_type == "categorical":
+        elif self.var_type in {"boolean", "categorical", "datetime"}:
             return {"bar_plot": self._plot_bar()}
 
     def _plot_histogram_and_boxplot(self):
@@ -169,9 +175,7 @@ Missing Values: {self.missing}
         ax1, ax2 = fig.subplots(nrows=2, ncols=1)
 
         if self.TARGET_DATA.nunique() in range(1, 11):
-            palette = list(
-                self._color_palette(n_colors=self.TARGET_DATA.nunique()),
-            )
+            palette = f"dark:{self.graph_color}_r"
             sns.boxplot(
                 y=self.data, x=self.TARGET_DATA, palette=palette, ax=ax1
             )
@@ -182,6 +186,7 @@ Missing Values: {self.missing}
                 kde=True,
                 ax=ax2,
             )
+            self._COLOR_CODED_GRAPHS.add("histogram & boxplot")
         else:
             ax1.boxplot(self.data.dropna(), vert=False, notch=True)
             ax1.set_yticklabels([""])  # Remove y-tick labels
@@ -228,9 +233,10 @@ Missing Values: {self.missing}
                 x=self.data.index,
                 y=self.data,
                 hue=self.TARGET_DATA,
-                palette=self._color_palette(self.TARGET_DATA.nunique()),
+                palette=f"dark:{self.graph_color}_r",
                 ax=ax,
             )
+            self._COLOR_CODED_GRAPHS.add("run-plot")
         else:
             ax.plot(self.data, marker=".", color=self.graph_color)
 
@@ -263,24 +269,30 @@ Missing Values: {self.missing}
         fig = Fig(figsize=(6, 4), linewidth=1)
         ax = fig.subplots()
 
-        if self.TARGET_DATA.nunique() in range(1, 11):
+        if (
+            self.data.nunique() in range(1, 11)
+            and self.TARGET_DATA.nunique() in range(1, 11)
+            and len(self.data) == len(self.TARGET_DATA)
+            and set(self.data) != set(self.TARGET_DATA)
+        ):
             sns.countplot(
                 x=self.data,
                 hue=self.TARGET_DATA,
-                color=self.graph_color,
+                palette=f"dark:{self.graph_color}_r",
                 ax=ax,
             )
+            self._COLOR_CODED_GRAPHS.add("bar-plot")
         else:
             # Include no more than 10 of the most common values
             top_10 = self.data.value_counts().nlargest(10)
             sns.barplot(
-                x=top_10.index,
+                x=top_10.index.to_list(),
                 y=top_10,
-                palette=self._color_palette(n_colors=top_10.shape[0] + 1),
+                palette=f"dark:{self.graph_color}_r",
+                ax=ax,
             )
-
-        ax.tick_params(axis="x", rotation=45)
-        ax.set_title(f"Bar-plot of {self.name}", size=12)
+            ax.tick_params(axis="x", rotation=45)
+            ax.set_title(f"Bar-plot of {self.name}", size=12)
 
         # Annotate bars
         for p in ax.patches:
